@@ -12,14 +12,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import io
 import re
 import sys
+from unittest import mock
 
 import argparse
 import fixtures
 from keystoneauth1 import fixture
-import mock
-import six
 from testtools import matchers
 
 from magnumclient import exceptions
@@ -119,9 +119,13 @@ class ShellTest(utils.TestCase):
     def test_help_on_subcommand(self):
         required = [
             '.*?^usage: magnum bay-create',
-            '.*?^Create a bay.',
-            '.*?^Optional arguments:',
+            '.*?^Create a bay.'
         ]
+        # https://bugs.python.org/issue9694
+        if sys.version_info[:2] >= (3, 10):
+            required.append('.*?^Options:')
+        else:
+            required.append('.*?^Optional arguments:')
         stdout, stderr = self.shell('help bay-create')
         for r in required:
             self.assertThat((stdout + stderr),
@@ -231,8 +235,8 @@ class ShellTest(utils.TestCase):
         self.assertEqual(False, session_kwargs['verify'])
 
     @mock.patch('sys.argv', ['magnum'])
-    @mock.patch('sys.stdout', six.StringIO())
-    @mock.patch('sys.stderr', six.StringIO())
+    @mock.patch('sys.stdout', io.StringIO())
+    @mock.patch('sys.stderr', io.StringIO())
     def test_main_noargs(self):
         # Ensure that main works with no command-line arguments
         try:
